@@ -205,7 +205,7 @@ def allequal(a, b, flavor="numpy"):
     return result
 
 
-def areArraysEqual(arr1, arr2):
+def areArraysEqual(arr1, arr2, *, check_type=True):
     """Are both `arr1` and `arr2` equal arrays?
 
     Arguments can be regular NumPy arrays, chararray arrays or
@@ -217,8 +217,8 @@ def areArraysEqual(arr1, arr2):
     t1 = type(arr1)
     t2 = type(arr2)
 
-    if not ((hasattr(arr1, 'dtype') and arr1.dtype == arr2.dtype) or
-            issubclass(t1, t2) or issubclass(t2, t1)):
+    if check_type and not ((hasattr(arr1, 'dtype') and arr1.dtype == arr2.dtype) or
+                           issubclass(t1, t2) or issubclass(t2, t1)):
         return False
 
     return np.all(arr1 == arr2)
@@ -366,3 +366,13 @@ class ShowMemTime(PyTablesTestCase):
         print(f"VmSize: {vmsize:>7} kB\tVmRSS: {vmrss:>7} kB")
         print(f"VmData: {vmdata:>7} kB\tVmStk: {vmstk:>7} kB")
         print(f"VmExe:  {vmexe:>7} kB\tVmLib: {vmlib:>7} kB")
+
+
+try:
+    from unittest import makeSuite as make_suite
+except ImportError:
+    def make_suite(test_case_class, *, prefix=None):
+        loader = unittest.TestLoader()
+        if prefix:
+            loader.testMethodPrefix = prefix
+        return loader.loadTestsFromTestCase(test_case_class)
